LICENSE_WHITELIST = [
    "MIT",
    "MIT License",
    "Apache 2.0",
    "Apache-2.0",
    "LGPL",
    "BSD",
    "BSD License",
    "BSD-like",
    "",
    "Unknown",
    "(GPL-2.0 OR MIT)",
    "BSD-3-Clause",
    "None",
    "MPL-2.0",
    "ISC",
    "ASL 2",
    "Apache 2.0",
    "3-Clause BSD License",
]
